diff --git a/cli/command/cli.go b/cli/command/cli.go
index 6bd487c67b..ff4b78adc6 100644
--- a/cli/command/cli.go
+++ b/cli/command/cli.go
@@ -18,11 +18,11 @@ import (
"github.com/docker/docker/client"
"github.com/docker/go-connections/sockets"
"github.com/docker/go-connections/tlsconfig"
- "github.com/docker/notary"
- notaryclient "github.com/docker/notary/client"
- "github.com/docker/notary/passphrase"
"github.com/pkg/errors"
"github.com/spf13/cobra"
+ "github.com/theupdateframework/notary"
+ notaryclient "github.com/theupdateframework/notary/client"
+ "github.com/theupdateframework/notary/passphrase"
"golang.org/x/net/context"
)
diff --git a/cli/command/image/trust.go b/cli/command/image/trust.go
index 2a443661c4..ec8a6fe0db 100644
--- a/cli/command/image/trust.go
+++ b/cli/command/image/trust.go
@@ -14,11 +14,11 @@ import (
registrytypes "github.com/docker/docker/api/types/registry"
"github.com/docker/docker/pkg/jsonmessage"
"github.com/docker/docker/registry"
- "github.com/docker/notary/client"
- "github.com/docker/notary/tuf/data"
digest "github.com/opencontainers/go-digest"
"github.com/pkg/errors"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary/client"
+ "github.com/theupdateframework/notary/tuf/data"
"golang.org/x/net/context"
)
diff --git a/cli/command/image/trust_test.go b/cli/command/image/trust_test.go
index 6356438a3a..6071ebdea5 100644
--- a/cli/command/image/trust_test.go
+++ b/cli/command/image/trust_test.go
@@ -8,11 +8,11 @@ import (
"github.com/docker/cli/cli/trust"
registrytypes "github.com/docker/docker/api/types/registry"
"github.com/docker/docker/registry"
- "github.com/docker/notary/client"
- "github.com/docker/notary/passphrase"
- "github.com/docker/notary/trustpinning"
"github.com/stretchr/testify/assert"
"github.com/stretchr/testify/require"
+ "github.com/theupdateframework/notary/client"
+ "github.com/theupdateframework/notary/passphrase"
+ "github.com/theupdateframework/notary/trustpinning"
)
func unsetENV() {
diff --git a/cli/command/service/trust.go b/cli/command/service/trust.go
index 4bfb6b590e..8bf9149764 100644
--- a/cli/command/service/trust.go
+++ b/cli/command/service/trust.go
@@ -8,10 +8,10 @@ import (
"github.com/docker/distribution/reference"
"github.com/docker/docker/api/types/swarm"
"github.com/docker/docker/registry"
- "github.com/docker/notary/tuf/data"
"github.com/opencontainers/go-digest"
"github.com/pkg/errors"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary/tuf/data"
"golang.org/x/net/context"
)
diff --git a/cli/command/trust/client_test.go b/cli/command/trust/client_test.go
index 028083591f..cc4fec5074 100644
--- a/cli/command/trust/client_test.go
+++ b/cli/command/trust/client_test.go
@@ -2,14 +2,14 @@ package trust
import (
"github.com/docker/cli/cli/trust"
- "github.com/docker/notary/client"
- "github.com/docker/notary/client/changelist"
- "github.com/docker/notary/cryptoservice"
- "github.com/docker/notary/passphrase"
- "github.com/docker/notary/storage"
- "github.com/docker/notary/trustmanager"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/signed"
+ "github.com/theupdateframework/notary/client"
+ "github.com/theupdateframework/notary/client/changelist"
+ "github.com/theupdateframework/notary/cryptoservice"
+ "github.com/theupdateframework/notary/passphrase"
+ "github.com/theupdateframework/notary/storage"
+ "github.com/theupdateframework/notary/trustmanager"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/signed"
)
// Sample mock CLI interfaces
diff --git a/cli/command/trust/helpers.go b/cli/command/trust/helpers.go
index 60d38815d3..b2819d2eda 100644
--- a/cli/command/trust/helpers.go
+++ b/cli/command/trust/helpers.go
@@ -4,8 +4,8 @@ import (
"strings"
"github.com/docker/cli/cli/trust"
- "github.com/docker/notary/client"
- "github.com/docker/notary/tuf/data"
+ "github.com/theupdateframework/notary/client"
+ "github.com/theupdateframework/notary/tuf/data"
)
const releasedRoleName = "Repo Admin"
diff --git a/cli/command/trust/helpers_test.go b/cli/command/trust/helpers_test.go
index c3113c65ec..a13eae2d6e 100644
--- a/cli/command/trust/helpers_test.go
+++ b/cli/command/trust/helpers_test.go
@@ -5,9 +5,9 @@ import (
"os"
"testing"
- "github.com/docker/notary/client"
- "github.com/docker/notary/passphrase"
- "github.com/docker/notary/trustpinning"
+ "github.com/theupdateframework/notary/client"
+ "github.com/theupdateframework/notary/passphrase"
+ "github.com/theupdateframework/notary/trustpinning"
"github.com/stretchr/testify/assert"
)
diff --git a/cli/command/trust/key_generate.go b/cli/command/trust/key_generate.go
index d12f21ce77..47223c3d9d 100644
--- a/cli/command/trust/key_generate.go
+++ b/cli/command/trust/key_generate.go
@@ -12,12 +12,12 @@ import (
"github.com/docker/cli/cli"
"github.com/docker/cli/cli/command"
"github.com/docker/cli/cli/trust"
- "github.com/docker/notary"
- "github.com/docker/notary/trustmanager"
- "github.com/docker/notary/tuf/data"
- tufutils "github.com/docker/notary/tuf/utils"
"github.com/pkg/errors"
"github.com/spf13/cobra"
+ "github.com/theupdateframework/notary"
+ "github.com/theupdateframework/notary/trustmanager"
+ "github.com/theupdateframework/notary/tuf/data"
+ tufutils "github.com/theupdateframework/notary/tuf/utils"
)
type keyGenerateOptions struct {
diff --git a/cli/command/trust/key_generate_test.go b/cli/command/trust/key_generate_test.go
index 4843f6af4c..faf6f31873 100644
--- a/cli/command/trust/key_generate_test.go
+++ b/cli/command/trust/key_generate_test.go
@@ -11,11 +11,11 @@ import (
"github.com/docker/cli/cli/config"
"github.com/docker/cli/internal/test"
"github.com/docker/cli/internal/test/testutil"
- "github.com/docker/notary"
- "github.com/docker/notary/passphrase"
- "github.com/docker/notary/trustmanager"
- tufutils "github.com/docker/notary/tuf/utils"
"github.com/stretchr/testify/assert"
+ "github.com/theupdateframework/notary"
+ "github.com/theupdateframework/notary/passphrase"
+ "github.com/theupdateframework/notary/trustmanager"
+ tufutils "github.com/theupdateframework/notary/tuf/utils"
)
func TestTrustKeyGenerateErrors(t *testing.T) {
diff --git a/cli/command/trust/key_load.go b/cli/command/trust/key_load.go
index 86e9990fdb..9263cbda47 100644
--- a/cli/command/trust/key_load.go
+++ b/cli/command/trust/key_load.go
@@ -10,12 +10,12 @@ import (
"github.com/docker/cli/cli"
"github.com/docker/cli/cli/command"
"github.com/docker/cli/cli/trust"
- "github.com/docker/notary"
- "github.com/docker/notary/storage"
- "github.com/docker/notary/trustmanager"
- tufutils "github.com/docker/notary/tuf/utils"
"github.com/pkg/errors"
"github.com/spf13/cobra"
+ "github.com/theupdateframework/notary"
+ "github.com/theupdateframework/notary/storage"
+ "github.com/theupdateframework/notary/trustmanager"
+ tufutils "github.com/theupdateframework/notary/tuf/utils"
)
const (
diff --git a/cli/command/trust/key_load_test.go b/cli/command/trust/key_load_test.go
index 5959a81192..5902b36667 100644
--- a/cli/command/trust/key_load_test.go
+++ b/cli/command/trust/key_load_test.go
@@ -11,12 +11,12 @@ import (
"github.com/docker/cli/cli/config"
"github.com/docker/cli/internal/test"
"github.com/docker/cli/internal/test/testutil"
- "github.com/docker/notary"
- "github.com/docker/notary/passphrase"
- "github.com/docker/notary/storage"
- "github.com/docker/notary/trustmanager"
- tufutils "github.com/docker/notary/tuf/utils"
"github.com/stretchr/testify/assert"
+ "github.com/theupdateframework/notary"
+ "github.com/theupdateframework/notary/passphrase"
+ "github.com/theupdateframework/notary/storage"
+ "github.com/theupdateframework/notary/trustmanager"
+ tufutils "github.com/theupdateframework/notary/tuf/utils"
)
func TestTrustKeyLoadErrors(t *testing.T) {
diff --git a/cli/command/trust/revoke.go b/cli/command/trust/revoke.go
index 23b423a39a..df2a22aa4d 100644
--- a/cli/command/trust/revoke.go
+++ b/cli/command/trust/revoke.go
@@ -9,10 +9,10 @@ import (
"github.com/docker/cli/cli/command"
"github.com/docker/cli/cli/command/image"
"github.com/docker/cli/cli/trust"
- "github.com/docker/notary/client"
- "github.com/docker/notary/tuf/data"
"github.com/pkg/errors"
"github.com/spf13/cobra"
+ "github.com/theupdateframework/notary/client"
+ "github.com/theupdateframework/notary/tuf/data"
)
type revokeOptions struct {
diff --git a/cli/command/trust/revoke_test.go b/cli/command/trust/revoke_test.go
index 5a6e105b16..ea93accdf9 100644
--- a/cli/command/trust/revoke_test.go
+++ b/cli/command/trust/revoke_test.go
@@ -7,11 +7,11 @@ import (
"github.com/docker/cli/internal/test"
"github.com/docker/cli/internal/test/testutil"
- "github.com/docker/notary/client"
- "github.com/docker/notary/passphrase"
- "github.com/docker/notary/trustpinning"
"github.com/stretchr/testify/assert"
"github.com/stretchr/testify/require"
+ "github.com/theupdateframework/notary/client"
+ "github.com/theupdateframework/notary/passphrase"
+ "github.com/theupdateframework/notary/trustpinning"
)
func TestTrustRevokeCommandErrors(t *testing.T) {
diff --git a/cli/command/trust/sign.go b/cli/command/trust/sign.go
index af40e206e7..98bf1fb197 100644
--- a/cli/command/trust/sign.go
+++ b/cli/command/trust/sign.go
@@ -12,10 +12,10 @@ import (
"github.com/docker/cli/cli/command"
"github.com/docker/cli/cli/command/image"
"github.com/docker/cli/cli/trust"
- "github.com/docker/notary/client"
- "github.com/docker/notary/tuf/data"
"github.com/pkg/errors"
"github.com/spf13/cobra"
+ "github.com/theupdateframework/notary/client"
+ "github.com/theupdateframework/notary/tuf/data"
)
func newSignCommand(dockerCli command.Cli) *cobra.Command {
diff --git a/cli/command/trust/sign_test.go b/cli/command/trust/sign_test.go
index 5334004397..ea67618bcd 100644
--- a/cli/command/trust/sign_test.go
+++ b/cli/command/trust/sign_test.go
@@ -12,14 +12,14 @@ import (
"github.com/docker/cli/cli/trust"
"github.com/docker/cli/internal/test"
"github.com/docker/cli/internal/test/testutil"
- "github.com/docker/notary"
- "github.com/docker/notary/client"
- "github.com/docker/notary/client/changelist"
- "github.com/docker/notary/passphrase"
- "github.com/docker/notary/trustpinning"
- "github.com/docker/notary/tuf/data"
"github.com/stretchr/testify/assert"
"github.com/stretchr/testify/require"
+ "github.com/theupdateframework/notary"
+ "github.com/theupdateframework/notary/client"
+ "github.com/theupdateframework/notary/client/changelist"
+ "github.com/theupdateframework/notary/passphrase"
+ "github.com/theupdateframework/notary/trustpinning"
+ "github.com/theupdateframework/notary/tuf/data"
)
const passwd = "password"
diff --git a/cli/command/trust/signer_add.go b/cli/command/trust/signer_add.go
index 8a9418f02b..874915cb1e 100644
--- a/cli/command/trust/signer_add.go
+++ b/cli/command/trust/signer_add.go
@@ -15,11 +15,11 @@ import (
"github.com/docker/cli/cli/command/image"
"github.com/docker/cli/cli/trust"
"github.com/docker/cli/opts"
- "github.com/docker/notary/client"
- "github.com/docker/notary/tuf/data"
- tufutils "github.com/docker/notary/tuf/utils"
"github.com/pkg/errors"
"github.com/spf13/cobra"
+ "github.com/theupdateframework/notary/client"
+ "github.com/theupdateframework/notary/tuf/data"
+ tufutils "github.com/theupdateframework/notary/tuf/utils"
)
type signerAddOptions struct {
diff --git a/cli/command/trust/signer_add_test.go b/cli/command/trust/signer_add_test.go
index 075613f84b..a27f161cb7 100644
--- a/cli/command/trust/signer_add_test.go
+++ b/cli/command/trust/signer_add_test.go
@@ -10,8 +10,8 @@ import (
"github.com/docker/cli/cli/config"
"github.com/docker/cli/internal/test"
"github.com/docker/cli/internal/test/testutil"
- "github.com/docker/notary"
"github.com/stretchr/testify/assert"
+ "github.com/theupdateframework/notary"
)
func TestTrustSignerAddErrors(t *testing.T) {
diff --git a/cli/command/trust/signer_remove.go b/cli/command/trust/signer_remove.go
index 2ac4224434..6b35b3610e 100644
--- a/cli/command/trust/signer_remove.go
+++ b/cli/command/trust/signer_remove.go
@@ -10,10 +10,10 @@ import (
"github.com/docker/cli/cli/command"
"github.com/docker/cli/cli/command/image"
"github.com/docker/cli/cli/trust"
- "github.com/docker/notary/client"
- "github.com/docker/notary/tuf/data"
"github.com/pkg/errors"
"github.com/spf13/cobra"
+ "github.com/theupdateframework/notary/client"
+ "github.com/theupdateframework/notary/tuf/data"
)
type signerRemoveOptions struct {
diff --git a/cli/command/trust/signer_remove_test.go b/cli/command/trust/signer_remove_test.go
index f0ab695c89..890fbf37a8 100644
--- a/cli/command/trust/signer_remove_test.go
+++ b/cli/command/trust/signer_remove_test.go
@@ -6,9 +6,9 @@ import (
"github.com/docker/cli/internal/test"
"github.com/docker/cli/internal/test/testutil"
- "github.com/docker/notary/client"
- "github.com/docker/notary/tuf/data"
"github.com/stretchr/testify/assert"
+ "github.com/theupdateframework/notary/client"
+ "github.com/theupdateframework/notary/tuf/data"
)
func TestTrustSignerRemoveErrors(t *testing.T) {
diff --git a/cli/command/trust/view.go b/cli/command/trust/view.go
index 37fc0bf802..8dd2e47347 100644
--- a/cli/command/trust/view.go
+++ b/cli/command/trust/view.go
@@ -13,11 +13,11 @@ import (
"github.com/docker/cli/cli/command/formatter"
"github.com/docker/cli/cli/command/image"
"github.com/docker/cli/cli/trust"
- "github.com/docker/notary"
- "github.com/docker/notary/client"
- "github.com/docker/notary/tuf/data"
"github.com/sirupsen/logrus"
"github.com/spf13/cobra"
+ "github.com/theupdateframework/notary"
+ "github.com/theupdateframework/notary/client"
+ "github.com/theupdateframework/notary/tuf/data"
)
// trustTagKey represents a unique signed tag and hex-encoded hash pair
diff --git a/cli/command/trust/view_test.go b/cli/command/trust/view_test.go
index c75680043a..b22fbce458 100644
--- a/cli/command/trust/view_test.go
+++ b/cli/command/trust/view_test.go
@@ -9,11 +9,11 @@ import (
"github.com/docker/cli/internal/test"
"github.com/docker/cli/internal/test/testutil"
dockerClient "github.com/docker/docker/client"
- "github.com/docker/notary"
- "github.com/docker/notary/client"
- "github.com/docker/notary/tuf/data"
"github.com/gotestyourself/gotestyourself/golden"
"github.com/stretchr/testify/assert"
+ "github.com/theupdateframework/notary"
+ "github.com/theupdateframework/notary/client"
+ "github.com/theupdateframework/notary/tuf/data"
)
type fakeClient struct {
diff --git a/cli/trust/trust.go b/cli/trust/trust.go
index c87ad7be8e..3372c1312f 100644
--- a/cli/trust/trust.go
+++ b/cli/trust/trust.go
@@ -20,17 +20,17 @@ import (
registrytypes "github.com/docker/docker/api/types/registry"
"github.com/docker/docker/registry"
"github.com/docker/go-connections/tlsconfig"
- "github.com/docker/notary"
- "github.com/docker/notary/client"
- "github.com/docker/notary/passphrase"
- "github.com/docker/notary/storage"
- "github.com/docker/notary/trustmanager"
- "github.com/docker/notary/trustpinning"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/signed"
digest "github.com/opencontainers/go-digest"
"github.com/pkg/errors"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary"
+ "github.com/theupdateframework/notary/client"
+ "github.com/theupdateframework/notary/passphrase"
+ "github.com/theupdateframework/notary/storage"
+ "github.com/theupdateframework/notary/trustmanager"
+ "github.com/theupdateframework/notary/trustpinning"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/signed"
"golang.org/x/net/context"
)
diff --git a/cli/trust/trust_test.go b/cli/trust/trust_test.go
index da9c3a8688..ea5971482e 100644
--- a/cli/trust/trust_test.go
+++ b/cli/trust/trust_test.go
@@ -6,12 +6,12 @@ import (
"testing"
"github.com/docker/distribution/reference"
- "github.com/docker/notary/client"
- "github.com/docker/notary/passphrase"
- "github.com/docker/notary/trustpinning"
digest "github.com/opencontainers/go-digest"
"github.com/stretchr/testify/assert"
"github.com/stretchr/testify/require"
+ "github.com/theupdateframework/notary/client"
+ "github.com/theupdateframework/notary/passphrase"
+ "github.com/theupdateframework/notary/trustpinning"
)
func TestGetTag(t *testing.T) {
diff --git a/internal/test/cli.go b/internal/test/cli.go
index 1002c166d6..3133d68960 100644
--- a/internal/test/cli.go
+++ b/internal/test/cli.go
@@ -11,7 +11,7 @@ import (
"github.com/docker/cli/cli/config/configfile"
"github.com/docker/cli/cli/trust"
"github.com/docker/docker/client"
- notaryclient "github.com/docker/notary/client"
+ notaryclient "github.com/theupdateframework/notary/client"
)
type notaryClientFuncType func(imgRefAndAuth trust.ImageRefAndAuth, actions []string) (notaryclient.Repository, error)
diff --git a/vendor.conf b/vendor.conf
index 7c8a85e891..cb2fd1eb7c 100755
--- a/vendor.conf
+++ b/vendor.conf
@@ -14,7 +14,6 @@ github.com/docker/go d30aec9fd63c35133f8f79c3412ad91a3b08be06
github.com/docker/go-connections 3ede32e2033de7505e6500d6c868c2b9ed9f169d
github.com/docker/go-events 9461782956ad83b30282bf90e31fa6a70c255ba9
github.com/docker/go-units 9e638d38cf6977a37a8ea0078f3ee75a7cdb2dd1
-github.com/docker/notary 5d55a30c1bec010a8c6df4c09889acfb4e0a7942
github.com/docker/swarmkit 872861d2ae46958af7ead1d5fffb092c73afbaf0
github.com/flynn-archive/go-shlex 3f9db97f856818214da2e1057f8ad84803971cff
github.com/gogo/protobuf v0.4
@@ -40,6 +39,7 @@ github.com/sirupsen/logrus v1.0.3
github.com/spf13/cobra 7b2c5ac9fc04fc5efafb60700713d4fa609b777b
github.com/spf13/pflag 97afa5e7ca8a08a383cb259e06636b5e2cc7897f
github.com/stretchr/testify 4d4bfba8f1d1027c4fdbe371823030df51419987
+github.com/theupdateframework/notary 05985dc5d1c71ee6c387e9cd276a00b9d424af53
github.com/tonistiigi/fsutil dea3a0da73aee887fc02142d995be764106ac5e2
github.com/xeipuuv/gojsonpointer e0fe6f68307607d540ed8eac07a342c33fa1b54a
github.com/xeipuuv/gojsonreference e02fc20de94c78484cd5ffb007f8af96be030a45
diff --git a/vendor/github.com/docker/notary/LICENSE b/vendor/github.com/theupdateframework/notary/LICENSE
similarity index 100%
rename from vendor/github.com/docker/notary/LICENSE
rename to vendor/github.com/theupdateframework/notary/LICENSE
diff --git a/vendor/github.com/docker/notary/README.md b/vendor/github.com/theupdateframework/notary/README.md
similarity index 81%
rename from vendor/github.com/docker/notary/README.md
rename to vendor/github.com/theupdateframework/notary/README.md
index 01af5d9b30..83c0487335 100644
--- a/vendor/github.com/docker/notary/README.md
+++ b/vendor/github.com/theupdateframework/notary/README.md
@@ -1,11 +1,22 @@
-# Notary
-[![Circle CI](https://circleci.com/gh/docker/notary/tree/master.svg?style=shield)](https://circleci.com/gh/docker/notary/tree/master) [![CodeCov](https://codecov.io/github/docker/notary/coverage.svg?branch=master)](https://codecov.io/github/docker/notary) [![GoReportCard](https://goreportcard.com/badge/docker/notary)](https://goreportcard.com/report/github.com/docker/notary)
+
+
+[![Circle CI](https://circleci.com/gh/theupdateframework/notary/tree/master.svg?style=shield)](https://circleci.com/gh/theupdateframework/notary/tree/master) [![CodeCov](https://codecov.io/github/theupdateframework/notary/coverage.svg?branch=master)](https://codecov.io/github/theupdateframework/notary) [![GoReportCard](https://goreportcard.com/badge/theupdateframework/notary)](https://goreportcard.com/report/github.com/theupdateframework/notary)
+
+# Notice
+
+The Notary project has officially been accepted in to the Cloud Native Computing Foundation (CNCF).
+It has moved to https://github.com/theupdateframework/notary. Any downstream consumers should update
+their Go imports to use this new location, which will be the canonical location going forward.
+
+We have moved the repo in GitHub, which will allow existing importers to continue using the old
+location via GitHub's redirect.
+
+# Overview
The Notary project comprises a [server](cmd/notary-server) and a [client](cmd/notary) for running and interacting
with trusted collections. Please see the [service architecture](docs/service_architecture.md) documentation
for more information.
-
Notary aims to make the internet more secure by making it easy for people to
publish and verify content. We often rely on TLS to secure our communications
with a web server which is inherently flawed, as any compromise of the server
@@ -41,7 +52,7 @@ Any security vulnerabilities can be reported to security@docker.com.
# Getting started with the Notary CLI
-Please get the Notary Client CLI binary from [the official releases page](https://github.com/docker/notary/releases) or you can [build one yourself](#building-notary).
+Please get the Notary Client CLI binary from [the official releases page](https://github.com/theupdateframework/notary/releases) or you can [build one yourself](#building-notary).
The version of Notary server and signer should be greater than or equal to Notary CLI's version to ensure feature compatibility (ex: CLI version 0.2, server/signer version >= 0.2), and all official releases are associated with GitHub tags.
To use the Notary CLI with Docker hub images, please have a look at our
@@ -53,7 +64,7 @@ For more advanced usage, please see the
To use the CLI against a local Notary server rather than against Docker Hub:
1. Please ensure that you have [docker and docker-compose](http://docs.docker.com/compose/install/) installed.
-1. `git clone https://github.com/docker/notary.git` and from the cloned repository path,
+1. `git clone https://github.com/theupdateframework/notary.git` and from the cloned repository path,
start up a local Notary server and signer and copy the config file and testing certs to your
local notary config directory:
@@ -78,8 +89,8 @@ to use `notary` with Docker images.
## Building Notary
-Note that our [latest stable release](https://github.com/docker/notary/releases) is at the head of the
-[releases branch](https://github.com/docker/notary/tree/releases). The master branch is the development
+Note that our [latest stable release](https://github.com/theupdateframework/notary/releases) is at the head of the
+[releases branch](https://github.com/theupdateframework/notary/tree/releases). The master branch is the development
branch and contains features for the next release.
Prerequisites:
@@ -102,4 +113,4 @@ $GOPATH/
notary/
```
-To build the server and signer, please run `docker-compose build`.
\ No newline at end of file
+To build the server and signer, please run `docker-compose build`.
diff --git a/vendor/github.com/docker/notary/client/changelist/change.go b/vendor/github.com/theupdateframework/notary/client/changelist/change.go
similarity index 98%
rename from vendor/github.com/docker/notary/client/changelist/change.go
rename to vendor/github.com/theupdateframework/notary/client/changelist/change.go
index f9fa552d00..d445767a7b 100644
--- a/vendor/github.com/docker/notary/client/changelist/change.go
+++ b/vendor/github.com/theupdateframework/notary/client/changelist/change.go
@@ -1,7 +1,7 @@
package changelist
import (
- "github.com/docker/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/data"
)
// Scopes for TUFChanges are simply the TUF roles.
diff --git a/vendor/github.com/docker/notary/client/changelist/changelist.go b/vendor/github.com/theupdateframework/notary/client/changelist/changelist.go
similarity index 100%
rename from vendor/github.com/docker/notary/client/changelist/changelist.go
rename to vendor/github.com/theupdateframework/notary/client/changelist/changelist.go
diff --git a/vendor/github.com/docker/notary/client/changelist/file_changelist.go b/vendor/github.com/theupdateframework/notary/client/changelist/file_changelist.go
similarity index 100%
rename from vendor/github.com/docker/notary/client/changelist/file_changelist.go
rename to vendor/github.com/theupdateframework/notary/client/changelist/file_changelist.go
diff --git a/vendor/github.com/docker/notary/client/changelist/interface.go b/vendor/github.com/theupdateframework/notary/client/changelist/interface.go
similarity index 97%
rename from vendor/github.com/docker/notary/client/changelist/interface.go
rename to vendor/github.com/theupdateframework/notary/client/changelist/interface.go
index 70dc0a2d0e..e8fb824779 100644
--- a/vendor/github.com/docker/notary/client/changelist/interface.go
+++ b/vendor/github.com/theupdateframework/notary/client/changelist/interface.go
@@ -1,6 +1,6 @@
package changelist
-import "github.com/docker/notary/tuf/data"
+import "github.com/theupdateframework/notary/tuf/data"
// Changelist is the interface for all TUF change lists
type Changelist interface {
diff --git a/vendor/github.com/docker/notary/client/client.go b/vendor/github.com/theupdateframework/notary/client/client.go
similarity index 98%
rename from vendor/github.com/docker/notary/client/client.go
rename to vendor/github.com/theupdateframework/notary/client/client.go
index 81411d2440..217e96235c 100644
--- a/vendor/github.com/docker/notary/client/client.go
+++ b/vendor/github.com/theupdateframework/notary/client/client.go
@@ -17,9 +17,9 @@ Use this package by creating a new repository object and calling methods on it.
"github.com/docker/distribution/registry/client/auth"
"github.com/docker/distribution/registry/client/auth/challenge"
"github.com/docker/distribution/registry/client/transport"
- notary "github.com/docker/notary/client"
- "github.com/docker/notary/trustpinning"
- "github.com/docker/notary/tuf/data"
+ notary "github.com/theupdateframework/notary/client"
+ "github.com/theupdateframework/notary/trustpinning"
+ "github.com/theupdateframework/notary/tuf/data"
)
func main() {
@@ -98,16 +98,16 @@ import (
"time"
canonicaljson "github.com/docker/go/canonical/json"
- "github.com/docker/notary"
- "github.com/docker/notary/client/changelist"
- "github.com/docker/notary/cryptoservice"
- store "github.com/docker/notary/storage"
- "github.com/docker/notary/trustpinning"
- "github.com/docker/notary/tuf"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/signed"
- "github.com/docker/notary/tuf/utils"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary"
+ "github.com/theupdateframework/notary/client/changelist"
+ "github.com/theupdateframework/notary/cryptoservice"
+ store "github.com/theupdateframework/notary/storage"
+ "github.com/theupdateframework/notary/trustpinning"
+ "github.com/theupdateframework/notary/tuf"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/signed"
+ "github.com/theupdateframework/notary/tuf/utils"
)
const (
diff --git a/vendor/github.com/docker/notary/client/delegations.go b/vendor/github.com/theupdateframework/notary/client/delegations.go
similarity index 97%
rename from vendor/github.com/docker/notary/client/delegations.go
rename to vendor/github.com/theupdateframework/notary/client/delegations.go
index 99a764680f..289654e227 100644
--- a/vendor/github.com/docker/notary/client/delegations.go
+++ b/vendor/github.com/theupdateframework/notary/client/delegations.go
@@ -4,12 +4,12 @@ import (
"encoding/json"
"fmt"
- "github.com/docker/notary"
- "github.com/docker/notary/client/changelist"
- store "github.com/docker/notary/storage"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/utils"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary"
+ "github.com/theupdateframework/notary/client/changelist"
+ store "github.com/theupdateframework/notary/storage"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/utils"
)
// AddDelegation creates changelist entries to add provided delegation public keys and paths.
diff --git a/vendor/github.com/docker/notary/client/errors.go b/vendor/github.com/theupdateframework/notary/client/errors.go
similarity index 96%
rename from vendor/github.com/docker/notary/client/errors.go
rename to vendor/github.com/theupdateframework/notary/client/errors.go
index ba7759c4f7..a2d4970eaa 100644
--- a/vendor/github.com/docker/notary/client/errors.go
+++ b/vendor/github.com/theupdateframework/notary/client/errors.go
@@ -3,7 +3,7 @@ package client
import (
"fmt"
- "github.com/docker/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/data"
)
// ErrRepoNotInitialized is returned when trying to publish an uninitialized
diff --git a/vendor/github.com/docker/notary/client/helpers.go b/vendor/github.com/theupdateframework/notary/client/helpers.go
similarity index 96%
rename from vendor/github.com/docker/notary/client/helpers.go
rename to vendor/github.com/theupdateframework/notary/client/helpers.go
index 186547eec8..179d27ecb0 100644
--- a/vendor/github.com/docker/notary/client/helpers.go
+++ b/vendor/github.com/theupdateframework/notary/client/helpers.go
@@ -6,13 +6,13 @@ import (
"net/http"
"time"
- "github.com/docker/notary/client/changelist"
- store "github.com/docker/notary/storage"
- "github.com/docker/notary/tuf"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/signed"
- "github.com/docker/notary/tuf/utils"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary/client/changelist"
+ store "github.com/theupdateframework/notary/storage"
+ "github.com/theupdateframework/notary/tuf"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/signed"
+ "github.com/theupdateframework/notary/tuf/utils"
)
// Use this to initialize remote HTTPStores from the config settings
diff --git a/vendor/github.com/docker/notary/client/interface.go b/vendor/github.com/theupdateframework/notary/client/interface.go
similarity index 91%
rename from vendor/github.com/docker/notary/client/interface.go
rename to vendor/github.com/theupdateframework/notary/client/interface.go
index ca09fb4ebc..4e6680dc0b 100644
--- a/vendor/github.com/docker/notary/client/interface.go
+++ b/vendor/github.com/theupdateframework/notary/client/interface.go
@@ -1,9 +1,9 @@
package client
import (
- "github.com/docker/notary/client/changelist"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/signed"
+ "github.com/theupdateframework/notary/client/changelist"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/signed"
)
// Repository represents the set of options that must be supported over a TUF repo.
diff --git a/vendor/github.com/docker/notary/client/repo.go b/vendor/github.com/theupdateframework/notary/client/repo.go
similarity index 80%
rename from vendor/github.com/docker/notary/client/repo.go
rename to vendor/github.com/theupdateframework/notary/client/repo.go
index 953fda10c3..cf2242b770 100644
--- a/vendor/github.com/docker/notary/client/repo.go
+++ b/vendor/github.com/theupdateframework/notary/client/repo.go
@@ -5,8 +5,8 @@ package client
import (
"fmt"
- "github.com/docker/notary"
- "github.com/docker/notary/trustmanager"
+ "github.com/theupdateframework/notary"
+ "github.com/theupdateframework/notary/trustmanager"
)
func getKeyStores(baseDir string, retriever notary.PassRetriever) ([]trustmanager.KeyStore, error) {
diff --git a/vendor/github.com/docker/notary/client/repo_pkcs11.go b/vendor/github.com/theupdateframework/notary/client/repo_pkcs11.go
similarity index 78%
rename from vendor/github.com/docker/notary/client/repo_pkcs11.go
rename to vendor/github.com/theupdateframework/notary/client/repo_pkcs11.go
index 3eccc2f7f2..a24d3e6049 100644
--- a/vendor/github.com/docker/notary/client/repo_pkcs11.go
+++ b/vendor/github.com/theupdateframework/notary/client/repo_pkcs11.go
@@ -5,9 +5,9 @@ package client
import (
"fmt"
- "github.com/docker/notary"
- "github.com/docker/notary/trustmanager"
- "github.com/docker/notary/trustmanager/yubikey"
+ "github.com/theupdateframework/notary"
+ "github.com/theupdateframework/notary/trustmanager"
+ "github.com/theupdateframework/notary/trustmanager/yubikey"
)
func getKeyStores(baseDir string, retriever notary.PassRetriever) ([]trustmanager.KeyStore, error) {
diff --git a/vendor/github.com/docker/notary/client/tufclient.go b/vendor/github.com/theupdateframework/notary/client/tufclient.go
similarity index 97%
rename from vendor/github.com/docker/notary/client/tufclient.go
rename to vendor/github.com/theupdateframework/notary/client/tufclient.go
index 2cf91e2723..17be930568 100644
--- a/vendor/github.com/docker/notary/client/tufclient.go
+++ b/vendor/github.com/theupdateframework/notary/client/tufclient.go
@@ -4,13 +4,13 @@ import (
"encoding/json"
"fmt"
- "github.com/docker/notary"
- store "github.com/docker/notary/storage"
- "github.com/docker/notary/trustpinning"
- "github.com/docker/notary/tuf"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/signed"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary"
+ store "github.com/theupdateframework/notary/storage"
+ "github.com/theupdateframework/notary/trustpinning"
+ "github.com/theupdateframework/notary/tuf"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/signed"
)
// tufClient is a usability wrapper around a raw TUF repo
diff --git a/vendor/github.com/docker/notary/client/witness.go b/vendor/github.com/theupdateframework/notary/client/witness.go
similarity index 92%
rename from vendor/github.com/docker/notary/client/witness.go
rename to vendor/github.com/theupdateframework/notary/client/witness.go
index b52239baae..ea6caa1b6f 100644
--- a/vendor/github.com/docker/notary/client/witness.go
+++ b/vendor/github.com/theupdateframework/notary/client/witness.go
@@ -1,9 +1,9 @@
package client
import (
- "github.com/docker/notary/client/changelist"
- "github.com/docker/notary/tuf"
- "github.com/docker/notary/tuf/data"
+ "github.com/theupdateframework/notary/client/changelist"
+ "github.com/theupdateframework/notary/tuf"
+ "github.com/theupdateframework/notary/tuf/data"
)
// Witness creates change objects to witness (i.e. re-sign) the given
diff --git a/vendor/github.com/docker/notary/const.go b/vendor/github.com/theupdateframework/notary/const.go
similarity index 100%
rename from vendor/github.com/docker/notary/const.go
rename to vendor/github.com/theupdateframework/notary/const.go
diff --git a/vendor/github.com/docker/notary/const_nowindows.go b/vendor/github.com/theupdateframework/notary/const_nowindows.go
similarity index 100%
rename from vendor/github.com/docker/notary/const_nowindows.go
rename to vendor/github.com/theupdateframework/notary/const_nowindows.go
diff --git a/vendor/github.com/docker/notary/const_windows.go b/vendor/github.com/theupdateframework/notary/const_windows.go
similarity index 100%
rename from vendor/github.com/docker/notary/const_windows.go
rename to vendor/github.com/theupdateframework/notary/const_windows.go
diff --git a/vendor/github.com/docker/notary/cryptoservice/certificate.go b/vendor/github.com/theupdateframework/notary/cryptoservice/certificate.go
similarity index 92%
rename from vendor/github.com/docker/notary/cryptoservice/certificate.go
rename to vendor/github.com/theupdateframework/notary/cryptoservice/certificate.go
index 26de510392..0270e89fb6 100644
--- a/vendor/github.com/docker/notary/cryptoservice/certificate.go
+++ b/vendor/github.com/theupdateframework/notary/cryptoservice/certificate.go
@@ -7,8 +7,8 @@ import (
"fmt"
"time"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/utils"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/utils"
)
// GenerateCertificate generates an X509 Certificate from a template, given a GUN and validity interval
diff --git a/vendor/github.com/docker/notary/cryptoservice/crypto_service.go b/vendor/github.com/theupdateframework/notary/cryptoservice/crypto_service.go
similarity index 96%
rename from vendor/github.com/docker/notary/cryptoservice/crypto_service.go
rename to vendor/github.com/theupdateframework/notary/cryptoservice/crypto_service.go
index 0773f1bfad..a558304f19 100644
--- a/vendor/github.com/docker/notary/cryptoservice/crypto_service.go
+++ b/vendor/github.com/theupdateframework/notary/cryptoservice/crypto_service.go
@@ -6,11 +6,11 @@ import (
"errors"
"fmt"
- "github.com/docker/notary"
- "github.com/docker/notary/trustmanager"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/utils"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary"
+ "github.com/theupdateframework/notary/trustmanager"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/utils"
)
var (
diff --git a/vendor/github.com/docker/notary/fips.go b/vendor/github.com/theupdateframework/notary/fips.go
similarity index 100%
rename from vendor/github.com/docker/notary/fips.go
rename to vendor/github.com/theupdateframework/notary/fips.go
diff --git a/vendor/github.com/docker/notary/notary.go b/vendor/github.com/theupdateframework/notary/notary.go
similarity index 100%
rename from vendor/github.com/docker/notary/notary.go
rename to vendor/github.com/theupdateframework/notary/notary.go
diff --git a/vendor/github.com/docker/notary/passphrase/passphrase.go b/vendor/github.com/theupdateframework/notary/passphrase/passphrase.go
similarity index 99%
rename from vendor/github.com/docker/notary/passphrase/passphrase.go
rename to vendor/github.com/theupdateframework/notary/passphrase/passphrase.go
index 69b46482f8..0d64773436 100644
--- a/vendor/github.com/docker/notary/passphrase/passphrase.go
+++ b/vendor/github.com/theupdateframework/notary/passphrase/passphrase.go
@@ -11,7 +11,7 @@ import (
"path/filepath"
"strings"
- "github.com/docker/notary"
+ "github.com/theupdateframework/notary"
"golang.org/x/crypto/ssh/terminal"
)
diff --git a/vendor/github.com/docker/notary/storage/errors.go b/vendor/github.com/theupdateframework/notary/storage/errors.go
similarity index 100%
rename from vendor/github.com/docker/notary/storage/errors.go
rename to vendor/github.com/theupdateframework/notary/storage/errors.go
diff --git a/vendor/github.com/docker/notary/storage/filestore.go b/vendor/github.com/theupdateframework/notary/storage/filestore.go
similarity index 99%
rename from vendor/github.com/docker/notary/storage/filestore.go
rename to vendor/github.com/theupdateframework/notary/storage/filestore.go
index 32b35eda1f..c150d1ce5e 100644
--- a/vendor/github.com/docker/notary/storage/filestore.go
+++ b/vendor/github.com/theupdateframework/notary/storage/filestore.go
@@ -10,8 +10,8 @@ import (
"path/filepath"
"strings"
- "github.com/docker/notary"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary"
)
// NewFileStore creates a fully configurable file store
diff --git a/vendor/github.com/docker/notary/storage/interfaces.go b/vendor/github.com/theupdateframework/notary/storage/interfaces.go
similarity index 95%
rename from vendor/github.com/docker/notary/storage/interfaces.go
rename to vendor/github.com/theupdateframework/notary/storage/interfaces.go
index c9ac03b602..c008f437a3 100644
--- a/vendor/github.com/docker/notary/storage/interfaces.go
+++ b/vendor/github.com/theupdateframework/notary/storage/interfaces.go
@@ -1,7 +1,7 @@
package storage
import (
- "github.com/docker/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/data"
)
// NoSizeLimit is represented as -1 for arguments to GetMeta
diff --git a/vendor/github.com/docker/notary/storage/memorystore.go b/vendor/github.com/theupdateframework/notary/storage/memorystore.go
similarity index 96%
rename from vendor/github.com/docker/notary/storage/memorystore.go
rename to vendor/github.com/theupdateframework/notary/storage/memorystore.go
index b4ae646692..0c92c69949 100644
--- a/vendor/github.com/docker/notary/storage/memorystore.go
+++ b/vendor/github.com/theupdateframework/notary/storage/memorystore.go
@@ -5,9 +5,9 @@ import (
"encoding/json"
"fmt"
- "github.com/docker/notary"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/utils"
+ "github.com/theupdateframework/notary"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/utils"
)
// NewMemoryStore returns a MetadataStore that operates entirely in memory.
diff --git a/vendor/github.com/docker/notary/storage/offlinestore.go b/vendor/github.com/theupdateframework/notary/storage/offlinestore.go
similarity index 96%
rename from vendor/github.com/docker/notary/storage/offlinestore.go
rename to vendor/github.com/theupdateframework/notary/storage/offlinestore.go
index 9a4faf6d44..c5062ae6bc 100644
--- a/vendor/github.com/docker/notary/storage/offlinestore.go
+++ b/vendor/github.com/theupdateframework/notary/storage/offlinestore.go
@@ -1,7 +1,7 @@
package storage
import (
- "github.com/docker/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/data"
)
// ErrOffline is used to indicate we are operating offline
diff --git a/vendor/github.com/docker/notary/trustmanager/errors.go b/vendor/github.com/theupdateframework/notary/trustmanager/errors.go
similarity index 100%
rename from vendor/github.com/docker/notary/trustmanager/errors.go
rename to vendor/github.com/theupdateframework/notary/trustmanager/errors.go
diff --git a/vendor/github.com/docker/notary/trustmanager/interfaces.go b/vendor/github.com/theupdateframework/notary/trustmanager/interfaces.go
similarity index 97%
rename from vendor/github.com/docker/notary/trustmanager/interfaces.go
rename to vendor/github.com/theupdateframework/notary/trustmanager/interfaces.go
index 5cce589832..9925d0ff50 100644
--- a/vendor/github.com/docker/notary/trustmanager/interfaces.go
+++ b/vendor/github.com/theupdateframework/notary/trustmanager/interfaces.go
@@ -1,7 +1,7 @@
package trustmanager
import (
- "github.com/docker/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/data"
)
// Storage implements the bare bones primitives (no hierarchy)
diff --git a/vendor/github.com/docker/notary/trustmanager/keys.go b/vendor/github.com/theupdateframework/notary/trustmanager/keys.go
similarity index 98%
rename from vendor/github.com/docker/notary/trustmanager/keys.go
rename to vendor/github.com/theupdateframework/notary/trustmanager/keys.go
index e90e4c9a38..8ad77a2fec 100644
--- a/vendor/github.com/docker/notary/trustmanager/keys.go
+++ b/vendor/github.com/theupdateframework/notary/trustmanager/keys.go
@@ -9,10 +9,10 @@ import (
"sort"
"strings"
- "github.com/docker/notary"
- tufdata "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/utils"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary"
+ tufdata "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/utils"
)
// Exporter is a simple interface for the two functions we need from the Storage interface
diff --git a/vendor/github.com/docker/notary/trustmanager/keystore.go b/vendor/github.com/theupdateframework/notary/trustmanager/keystore.go
similarity index 97%
rename from vendor/github.com/docker/notary/trustmanager/keystore.go
rename to vendor/github.com/theupdateframework/notary/trustmanager/keystore.go
index eb42dede9a..4383f8ed78 100644
--- a/vendor/github.com/docker/notary/trustmanager/keystore.go
+++ b/vendor/github.com/theupdateframework/notary/trustmanager/keystore.go
@@ -6,11 +6,11 @@ import (
"strings"
"sync"
- "github.com/docker/notary"
- store "github.com/docker/notary/storage"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/utils"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary"
+ store "github.com/theupdateframework/notary/storage"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/utils"
)
type keyInfoMap map[string]KeyInfo
diff --git a/vendor/github.com/docker/notary/trustmanager/yubikey/import.go b/vendor/github.com/theupdateframework/notary/trustmanager/yubikey/import.go
similarity index 87%
rename from vendor/github.com/docker/notary/trustmanager/yubikey/import.go
rename to vendor/github.com/theupdateframework/notary/trustmanager/yubikey/import.go
index a51af88bdf..680ded289c 100644
--- a/vendor/github.com/docker/notary/trustmanager/yubikey/import.go
+++ b/vendor/github.com/theupdateframework/notary/trustmanager/yubikey/import.go
@@ -6,10 +6,10 @@ import (
"encoding/pem"
"errors"
- "github.com/docker/notary"
- "github.com/docker/notary/trustmanager"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/utils"
+ "github.com/theupdateframework/notary"
+ "github.com/theupdateframework/notary/trustmanager"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/utils"
)
// YubiImport is a wrapper around the YubiStore that allows us to import private
diff --git a/vendor/github.com/docker/notary/trustmanager/yubikey/non_pkcs11.go b/vendor/github.com/theupdateframework/notary/trustmanager/yubikey/non_pkcs11.go
similarity index 100%
rename from vendor/github.com/docker/notary/trustmanager/yubikey/non_pkcs11.go
rename to vendor/github.com/theupdateframework/notary/trustmanager/yubikey/non_pkcs11.go
diff --git a/vendor/github.com/docker/notary/trustmanager/yubikey/pkcs11_darwin.go b/vendor/github.com/theupdateframework/notary/trustmanager/yubikey/pkcs11_darwin.go
similarity index 100%
rename from vendor/github.com/docker/notary/trustmanager/yubikey/pkcs11_darwin.go
rename to vendor/github.com/theupdateframework/notary/trustmanager/yubikey/pkcs11_darwin.go
diff --git a/vendor/github.com/docker/notary/trustmanager/yubikey/pkcs11_interface.go b/vendor/github.com/theupdateframework/notary/trustmanager/yubikey/pkcs11_interface.go
similarity index 100%
rename from vendor/github.com/docker/notary/trustmanager/yubikey/pkcs11_interface.go
rename to vendor/github.com/theupdateframework/notary/trustmanager/yubikey/pkcs11_interface.go
diff --git a/vendor/github.com/docker/notary/trustmanager/yubikey/pkcs11_linux.go b/vendor/github.com/theupdateframework/notary/trustmanager/yubikey/pkcs11_linux.go
similarity index 100%
rename from vendor/github.com/docker/notary/trustmanager/yubikey/pkcs11_linux.go
rename to vendor/github.com/theupdateframework/notary/trustmanager/yubikey/pkcs11_linux.go
diff --git a/vendor/github.com/docker/notary/trustmanager/yubikey/yubikeystore.go b/vendor/github.com/theupdateframework/notary/trustmanager/yubikey/yubikeystore.go
similarity index 99%
rename from vendor/github.com/docker/notary/trustmanager/yubikey/yubikeystore.go
rename to vendor/github.com/theupdateframework/notary/trustmanager/yubikey/yubikeystore.go
index 33715da350..1fd71eea95 100644
--- a/vendor/github.com/docker/notary/trustmanager/yubikey/yubikeystore.go
+++ b/vendor/github.com/theupdateframework/notary/trustmanager/yubikey/yubikeystore.go
@@ -16,13 +16,13 @@ import (
"os"
"time"
- "github.com/docker/notary"
- "github.com/docker/notary/trustmanager"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/signed"
- "github.com/docker/notary/tuf/utils"
"github.com/miekg/pkcs11"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary"
+ "github.com/theupdateframework/notary/trustmanager"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/signed"
+ "github.com/theupdateframework/notary/tuf/utils"
)
const (
diff --git a/vendor/github.com/docker/notary/trustpinning/certs.go b/vendor/github.com/theupdateframework/notary/trustpinning/certs.go
similarity index 98%
rename from vendor/github.com/docker/notary/trustpinning/certs.go
rename to vendor/github.com/theupdateframework/notary/trustpinning/certs.go
index c328a8314b..9be49ee102 100644
--- a/vendor/github.com/docker/notary/trustpinning/certs.go
+++ b/vendor/github.com/theupdateframework/notary/trustpinning/certs.go
@@ -6,10 +6,10 @@ import (
"fmt"
"strings"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/signed"
- "github.com/docker/notary/tuf/utils"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/signed"
+ "github.com/theupdateframework/notary/tuf/utils"
)
const wildcard = "*"
diff --git a/vendor/github.com/docker/notary/trustpinning/trustpin.go b/vendor/github.com/theupdateframework/notary/trustpinning/trustpin.go
similarity index 98%
rename from vendor/github.com/docker/notary/trustpinning/trustpin.go
rename to vendor/github.com/theupdateframework/notary/trustpinning/trustpin.go
index acad5a1369..67908f8b2c 100644
--- a/vendor/github.com/docker/notary/trustpinning/trustpin.go
+++ b/vendor/github.com/theupdateframework/notary/trustpinning/trustpin.go
@@ -5,9 +5,9 @@ import (
"fmt"
"strings"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/utils"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/utils"
)
// TrustPinConfig represents the configuration under the trust_pinning section of the config file
diff --git a/vendor/github.com/docker/notary/tuf/LICENSE b/vendor/github.com/theupdateframework/notary/tuf/LICENSE
similarity index 100%
rename from vendor/github.com/docker/notary/tuf/LICENSE
rename to vendor/github.com/theupdateframework/notary/tuf/LICENSE
diff --git a/vendor/github.com/docker/notary/tuf/README.md b/vendor/github.com/theupdateframework/notary/tuf/README.md
similarity index 100%
rename from vendor/github.com/docker/notary/tuf/README.md
rename to vendor/github.com/theupdateframework/notary/tuf/README.md
diff --git a/vendor/github.com/docker/notary/tuf/builder.go b/vendor/github.com/theupdateframework/notary/tuf/builder.go
similarity index 99%
rename from vendor/github.com/docker/notary/tuf/builder.go
rename to vendor/github.com/theupdateframework/notary/tuf/builder.go
index b868743774..db0a4d1114 100644
--- a/vendor/github.com/docker/notary/tuf/builder.go
+++ b/vendor/github.com/theupdateframework/notary/tuf/builder.go
@@ -4,12 +4,12 @@ import (
"fmt"
"github.com/docker/go/canonical/json"
- "github.com/docker/notary"
+ "github.com/theupdateframework/notary"
- "github.com/docker/notary/trustpinning"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/signed"
- "github.com/docker/notary/tuf/utils"
+ "github.com/theupdateframework/notary/trustpinning"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/signed"
+ "github.com/theupdateframework/notary/tuf/utils"
)
// ErrBuildDone is returned when any functions are called on RepoBuilder, and it
diff --git a/vendor/github.com/docker/notary/tuf/data/errors.go b/vendor/github.com/theupdateframework/notary/tuf/data/errors.go
similarity index 100%
rename from vendor/github.com/docker/notary/tuf/data/errors.go
rename to vendor/github.com/theupdateframework/notary/tuf/data/errors.go
diff --git a/vendor/github.com/docker/notary/tuf/data/keys.go b/vendor/github.com/theupdateframework/notary/tuf/data/keys.go
similarity index 100%
rename from vendor/github.com/docker/notary/tuf/data/keys.go
rename to vendor/github.com/theupdateframework/notary/tuf/data/keys.go
diff --git a/vendor/github.com/docker/notary/tuf/data/roles.go b/vendor/github.com/theupdateframework/notary/tuf/data/roles.go
similarity index 100%
rename from vendor/github.com/docker/notary/tuf/data/roles.go
rename to vendor/github.com/theupdateframework/notary/tuf/data/roles.go
diff --git a/vendor/github.com/docker/notary/tuf/data/root.go b/vendor/github.com/theupdateframework/notary/tuf/data/root.go
similarity index 100%
rename from vendor/github.com/docker/notary/tuf/data/root.go
rename to vendor/github.com/theupdateframework/notary/tuf/data/root.go
diff --git a/vendor/github.com/docker/notary/tuf/data/serializer.go b/vendor/github.com/theupdateframework/notary/tuf/data/serializer.go
similarity index 100%
rename from vendor/github.com/docker/notary/tuf/data/serializer.go
rename to vendor/github.com/theupdateframework/notary/tuf/data/serializer.go
diff --git a/vendor/github.com/docker/notary/tuf/data/snapshot.go b/vendor/github.com/theupdateframework/notary/tuf/data/snapshot.go
similarity index 99%
rename from vendor/github.com/docker/notary/tuf/data/snapshot.go
rename to vendor/github.com/theupdateframework/notary/tuf/data/snapshot.go
index 2341979537..2a07105ba5 100644
--- a/vendor/github.com/docker/notary/tuf/data/snapshot.go
+++ b/vendor/github.com/theupdateframework/notary/tuf/data/snapshot.go
@@ -5,8 +5,8 @@ import (
"fmt"
"github.com/docker/go/canonical/json"
- "github.com/docker/notary"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary"
)
// SignedSnapshot is a fully unpacked snapshot.json
diff --git a/vendor/github.com/docker/notary/tuf/data/targets.go b/vendor/github.com/theupdateframework/notary/tuf/data/targets.go
similarity index 100%
rename from vendor/github.com/docker/notary/tuf/data/targets.go
rename to vendor/github.com/theupdateframework/notary/tuf/data/targets.go
diff --git a/vendor/github.com/docker/notary/tuf/data/timestamp.go b/vendor/github.com/theupdateframework/notary/tuf/data/timestamp.go
similarity index 98%
rename from vendor/github.com/docker/notary/tuf/data/timestamp.go
rename to vendor/github.com/theupdateframework/notary/tuf/data/timestamp.go
index 883641cd73..baf4016ee9 100644
--- a/vendor/github.com/docker/notary/tuf/data/timestamp.go
+++ b/vendor/github.com/theupdateframework/notary/tuf/data/timestamp.go
@@ -5,7 +5,7 @@ import (
"fmt"
"github.com/docker/go/canonical/json"
- "github.com/docker/notary"
+ "github.com/theupdateframework/notary"
)
// SignedTimestamp is a fully unpacked timestamp.json
diff --git a/vendor/github.com/docker/notary/tuf/data/types.go b/vendor/github.com/theupdateframework/notary/tuf/data/types.go
similarity index 99%
rename from vendor/github.com/docker/notary/tuf/data/types.go
rename to vendor/github.com/theupdateframework/notary/tuf/data/types.go
index ba973e1f9d..6f9c112015 100644
--- a/vendor/github.com/docker/notary/tuf/data/types.go
+++ b/vendor/github.com/theupdateframework/notary/tuf/data/types.go
@@ -15,8 +15,8 @@ import (
"time"
"github.com/docker/go/canonical/json"
- "github.com/docker/notary"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary"
)
// GUN is a Globally Unique Name. It is used to identify trust collections.
diff --git a/vendor/github.com/docker/notary/tuf/signed/ed25519.go b/vendor/github.com/theupdateframework/notary/tuf/signed/ed25519.go
similarity index 94%
rename from vendor/github.com/docker/notary/tuf/signed/ed25519.go
rename to vendor/github.com/theupdateframework/notary/tuf/signed/ed25519.go
index e08daba355..b526085a44 100644
--- a/vendor/github.com/docker/notary/tuf/signed/ed25519.go
+++ b/vendor/github.com/theupdateframework/notary/tuf/signed/ed25519.go
@@ -4,9 +4,9 @@ import (
"crypto/rand"
"errors"
- "github.com/docker/notary/trustmanager"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/utils"
+ "github.com/theupdateframework/notary/trustmanager"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/utils"
)
type edCryptoKey struct {
diff --git a/vendor/github.com/docker/notary/tuf/signed/errors.go b/vendor/github.com/theupdateframework/notary/tuf/signed/errors.go
similarity index 98%
rename from vendor/github.com/docker/notary/tuf/signed/errors.go
rename to vendor/github.com/theupdateframework/notary/tuf/signed/errors.go
index 5d4ff04ab7..29ec40de27 100644
--- a/vendor/github.com/docker/notary/tuf/signed/errors.go
+++ b/vendor/github.com/theupdateframework/notary/tuf/signed/errors.go
@@ -4,7 +4,7 @@ import (
"fmt"
"strings"
- "github.com/docker/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/data"
)
// ErrInsufficientSignatures - can not create enough signatures on a piece of
diff --git a/vendor/github.com/docker/notary/tuf/signed/interface.go b/vendor/github.com/theupdateframework/notary/tuf/signed/interface.go
similarity index 96%
rename from vendor/github.com/docker/notary/tuf/signed/interface.go
rename to vendor/github.com/theupdateframework/notary/tuf/signed/interface.go
index 03b426f162..14f3a33fac 100644
--- a/vendor/github.com/docker/notary/tuf/signed/interface.go
+++ b/vendor/github.com/theupdateframework/notary/tuf/signed/interface.go
@@ -1,6 +1,6 @@
package signed
-import "github.com/docker/notary/tuf/data"
+import "github.com/theupdateframework/notary/tuf/data"
// KeyService provides management of keys locally. It will never
// accept or provide private keys. Communication between the KeyService
diff --git a/vendor/github.com/docker/notary/tuf/signed/sign.go b/vendor/github.com/theupdateframework/notary/tuf/signed/sign.go
similarity index 96%
rename from vendor/github.com/docker/notary/tuf/signed/sign.go
rename to vendor/github.com/theupdateframework/notary/tuf/signed/sign.go
index be1410d601..b3e329ce48 100644
--- a/vendor/github.com/docker/notary/tuf/signed/sign.go
+++ b/vendor/github.com/theupdateframework/notary/tuf/signed/sign.go
@@ -14,10 +14,10 @@ package signed
import (
"crypto/rand"
- "github.com/docker/notary/trustmanager"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/utils"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary/trustmanager"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/utils"
)
// Sign takes a data.Signed and a cryptoservice containing private keys,
diff --git a/vendor/github.com/docker/notary/tuf/signed/verifiers.go b/vendor/github.com/theupdateframework/notary/tuf/signed/verifiers.go
similarity index 99%
rename from vendor/github.com/docker/notary/tuf/signed/verifiers.go
rename to vendor/github.com/theupdateframework/notary/tuf/signed/verifiers.go
index e32b15378b..d5ce7f8625 100644
--- a/vendor/github.com/docker/notary/tuf/signed/verifiers.go
+++ b/vendor/github.com/theupdateframework/notary/tuf/signed/verifiers.go
@@ -11,8 +11,8 @@ import (
"math/big"
"github.com/agl/ed25519"
- "github.com/docker/notary/tuf/data"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary/tuf/data"
)
const (
diff --git a/vendor/github.com/docker/notary/tuf/signed/verify.go b/vendor/github.com/theupdateframework/notary/tuf/signed/verify.go
similarity index 97%
rename from vendor/github.com/docker/notary/tuf/signed/verify.go
rename to vendor/github.com/theupdateframework/notary/tuf/signed/verify.go
index c3bf1925ea..5ae2da4853 100644
--- a/vendor/github.com/docker/notary/tuf/signed/verify.go
+++ b/vendor/github.com/theupdateframework/notary/tuf/signed/verify.go
@@ -7,9 +7,9 @@ import (
"time"
"github.com/docker/go/canonical/json"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/utils"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/utils"
)
// Various basic signing errors
diff --git a/vendor/github.com/docker/notary/tuf/tuf.go b/vendor/github.com/theupdateframework/notary/tuf/tuf.go
similarity index 99%
rename from vendor/github.com/docker/notary/tuf/tuf.go
rename to vendor/github.com/theupdateframework/notary/tuf/tuf.go
index 2136e52dfe..74f6ceb593 100644
--- a/vendor/github.com/docker/notary/tuf/tuf.go
+++ b/vendor/github.com/theupdateframework/notary/tuf/tuf.go
@@ -8,11 +8,11 @@ import (
"strings"
"time"
- "github.com/docker/notary"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/signed"
- "github.com/docker/notary/tuf/utils"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/signed"
+ "github.com/theupdateframework/notary/tuf/utils"
)
// ErrSigVerifyFail - signature verification failed
diff --git a/vendor/github.com/docker/notary/tuf/utils/pkcs8.go b/vendor/github.com/theupdateframework/notary/tuf/utils/pkcs8.go
similarity index 99%
rename from vendor/github.com/docker/notary/tuf/utils/pkcs8.go
rename to vendor/github.com/theupdateframework/notary/tuf/utils/pkcs8.go
index cd18c68742..edcaa77ff7 100644
--- a/vendor/github.com/docker/notary/tuf/utils/pkcs8.go
+++ b/vendor/github.com/theupdateframework/notary/tuf/utils/pkcs8.go
@@ -48,7 +48,7 @@ import (
"golang.org/x/crypto/pbkdf2"
- "github.com/docker/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/data"
)
// Copy from crypto/x509
diff --git a/vendor/github.com/docker/notary/tuf/utils/role_sort.go b/vendor/github.com/theupdateframework/notary/tuf/utils/role_sort.go
similarity index 100%
rename from vendor/github.com/docker/notary/tuf/utils/role_sort.go
rename to vendor/github.com/theupdateframework/notary/tuf/utils/role_sort.go
diff --git a/vendor/github.com/docker/notary/tuf/utils/stack.go b/vendor/github.com/theupdateframework/notary/tuf/utils/stack.go
similarity index 100%
rename from vendor/github.com/docker/notary/tuf/utils/stack.go
rename to vendor/github.com/theupdateframework/notary/tuf/utils/stack.go
diff --git a/vendor/github.com/docker/notary/tuf/utils/utils.go b/vendor/github.com/theupdateframework/notary/tuf/utils/utils.go
similarity index 98%
rename from vendor/github.com/docker/notary/tuf/utils/utils.go
rename to vendor/github.com/theupdateframework/notary/tuf/utils/utils.go
index 2899a0340d..ada7dc8cc6 100644
--- a/vendor/github.com/docker/notary/tuf/utils/utils.go
+++ b/vendor/github.com/theupdateframework/notary/tuf/utils/utils.go
@@ -7,7 +7,7 @@ import (
"fmt"
"io"
- "github.com/docker/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/data"
)
// StrSliceContains checks if the given string appears in the slice
diff --git a/vendor/github.com/docker/notary/tuf/utils/x509.go b/vendor/github.com/theupdateframework/notary/tuf/utils/x509.go
similarity index 99%
rename from vendor/github.com/docker/notary/tuf/utils/x509.go
rename to vendor/github.com/theupdateframework/notary/tuf/utils/x509.go
index 2a6cf9777b..7738418ac2 100644
--- a/vendor/github.com/docker/notary/tuf/utils/x509.go
+++ b/vendor/github.com/theupdateframework/notary/tuf/utils/x509.go
@@ -17,9 +17,9 @@ import (
"time"
"github.com/agl/ed25519"
- "github.com/docker/notary"
- "github.com/docker/notary/tuf/data"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary"
+ "github.com/theupdateframework/notary/tuf/data"
)
// CanonicalKeyID returns the ID of the public bytes version of a TUF key.
diff --git a/vendor/github.com/docker/notary/storage/httpstore.go b/vendor/github.com/theupdateframework/notary/storage/httpstore.go
similarity index 97%
rename from vendor/github.com/docker/notary/storage/httpstore.go
rename to vendor/github.com/theupdateframework/notary/storage/httpstore.go
index d0523fb676..03392d4d12 100644
--- a/vendor/github.com/docker/notary/storage/httpstore.go
+++ b/vendor/github.com/theupdateframework/notary/storage/httpstore.go
@@ -3,7 +3,7 @@
// - Response bodies for error codes should be unmarshallable as:
// {"errors": [{..., "detail": }]}
// else validation error details, etc. will be unparsable. The errors
// should have a github.com/docker/notary/tuf/validation/SerializableError
// in the Details field.
// If writing your own server, please have a look at
// github.com/docker/distribution/registry/api/errcode
@@ -22,10 +22,10 @@ import (
"net/url"
"path"
- "github.com/docker/notary"
- "github.com/docker/notary/tuf/data"
- "github.com/docker/notary/tuf/validation"
"github.com/sirupsen/logrus"
+ "github.com/theupdateframework/notary"
+ "github.com/theupdateframework/notary/tuf/data"
+ "github.com/theupdateframework/notary/tuf/validation"
)
const (
@@ -3,7 +3,7 @@
// {"errors": [{..., "detail": }]}
// else validation error details, etc. will be unparsable. The errors
-// should have a github.com/docker/notary/tuf/validation/SerializableError
+// should have a github.com/theupdateframework/notary/tuf/validation/SerializableError
// in the Details field.
// If writing your own server, please have a look at
diff --git a/vendor/github.com/docker/notary/tuf/validation/errors.go b/vendor/github.com/theupdateframework/notary/tuf/validation/errors.go
similarity index 100%
rename from vendor/github.com/docker/notary/tuf/validation/errors.go
rename to vendor/github.com/theupdateframework/notary/tuf/validation/errors.go
diff --git a/vendor/github.com/docker/notary/vendor.conf b/vendor/github.com/theupdateframework/notary/vendor.conf
similarity index 100%
rename from vendor/github.com/docker/notary/vendor.conf
rename to vendor/github.com/theupdateframework/notary/vendor.conf